@@ -7,6 +7,7 @@ usage() {
     echo "USAGE: $0 [command]"
     echo "  test - run the waffle tests"
     echo "  lint - run flake8"
+    echo "  typecheck - run mypy"
     echo "  shell - open the Django shell"
     echo "  makemigrations - create a schema migration"
     exit 1
@@ -20,6 +21,8 @@ case "$CMD" in
         DJANGO_SETTINGS_MODULE=test_settings django-admin test waffle $@ ;;
     "lint" )
         flake8 waffle $@ ;;
+    "typecheck" )
+        mypy waffle $@ ;;
     "shell" )
         django-admin shell $@ ;;
     "makemigrations" )
