@@ -83,6 +83,13 @@ class Command(BaseCommand):
             dest='rollout',
             default=False,
             help='Turn on rollout mode.')
+        parser.add_argument(
+            '--testing', '-t',
+            action='store_true',
+            dest='testing',
+            default=False,
+            help='Turn on testing mode, allowing the flag to be specified via '
+                 'a querystring parameter.')
         parser.add_argument(
             '--create',
             action='store_true',
